==> owncloud-news_5.3.8%2Bdfsg.orig.tar.gz: news-5.3.8/l10n/it.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "La fonte contiene XML non valido",
    "Could not find a feed" : "Impossibile trovare una fonte",
    "Detected feed format is not supported" : "Il formato della fonte rilevato non è supportato",
    "SSL Certificate is invalid" : "Il certificato SSL non è valido",
    "Website not found" : "Sito web non trovato",
    "More redirects than allowed, aborting" : "Più redirezioni di quelle consentite, interruzione in corso",
    "Bigger than maximum allowed size" : "Più grande della dimensione massima consentita",
    "Request timed out" : "Richiesta scaduta",
    "Request failed, network connection unavailable!" : "Richiesta non riuscita, connessione di rete non disponibile!",
    "Request unauthorized. Are you logged in?" : "Richiesta non autorizzata. Hai effettuato l'accesso?",
    "Request forbidden. Are you an admin?" : "Richiesta vietata. Sei un amministratore?",
    "Token expired or app not enabled! Reload the page!" : "Token scaduto o applicazione non abilitata! Ricarica la pagina!",
    "Internal server error! Please check your " : "Errore interno del server! Controlla il tuo",
    "Request failed, ownCloud is in currently " : "Richiesta non riuscita, ownCloud è attualmente",
    "Can not add feed: Exists already" : "Impossible aggiungere la fonte: esiste già",
    "Articles without feed" : "Articoli senza fonte",
    "Can not add folder: Exists already" : "Impossibile aggiungere la cartella: esiste già",
    "Use ownCloud cron for updates" : "Utilizza il cron di ownCloud per gli aggiornamenti",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Disabilita questa opzione se esegui uno strumento di aggiornamento personalizzato come quello Python incluso nell'applicazione",
    "Purge interval" : "Intervallo di cancellazione",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Numero minimo di secondi dopo i quali le fonti e le cartelle eliminate sono rimosse dal database; valori inferiori a 60 secondi sono ignorati",
    "Maximum read count per feed" : "Numero massimo di letture per fonte",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Definisce la quantità massima di articoli che possono essere letti per ogni fonte che non saranno eliminati dall'operazione di pulitura; se vecchi articoli riappaiono dopo essere stati letti, incrementa questo valore; valori negativi come -1 disattiveranno completamente questa funzionalità",
    "Maximum redirects" : "Numero massimo di redizioni",
    "How many redirects the feed fetcher should follow" : "Quante redirezioni può seguire lo strumento di recupero delle fonti",
    "Maximum feed page size" : "Dimensione massima della pagina della fonte",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Dimensione massima in byte della fonte. Se la pagina RSS/Atom è più grande di questo valore, l'aggiornamento sarà interrotto",
    "Feed fetcher timeout" : "Ritardo massimo di attesa per il recupero della fonte",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Numero massimo di secondi di attesa per il caricamento di una fonte RSS o Atom; se richiede troppo tempo l'aggiornamento sarà interrotto",
    "Explore Service URL" : "URL del servizio Esplora",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Se specificato, questo URL del servizio sarà interrogato per visualizzare le fonti nella sezione di esplorazione. Per tornare al servizio di esplorazione integrato, lascia vuoto questo campo",
    "Saved" : "Salvato",
    "Download" : "Scarica",
    "Close" : "Chiudi",
    "Ajax cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "Rilevata la modalità Ajax di cron! Le tue fonti non saranno aggiornate correttamente. Si consiglia di utilizzare cron del sistema operativo o uno strumento di aggiornamento personalizzato.",
    "How to set up the operating system cron" : "Come configurare cron del sistema operativo",
    "How to set up a custom updater (faster and no possible deadlock) " : "Come configurare uno strumento di aggiornamento personalizzato (più veloce e senza blocchi)",
    "Subscribe" : "Sottoscrivi",
    "Refresh" : "Aggiorna",
    "No articles available" : "Nessun articolo disponibile",
    "No unread articles available" : "Non sono disponibili articoli non letti",
    "Open website" : "Apri sito web",
    "Star article" : "Aggiungi ai preferiti",
    "Unstar article" : "Rimuovi dai preferiti",
    "Keep article unread" : "Mantieni l'articolo come non letto",
    "Remove keep article unread" : "Rimuovi il mantenimento dell'articolo come non letto",
    "by" : "da",
    "from" : "da",
    "Play audio" : "Riproduci audio",
    "Download video" : "Scarica video",
    "Download audio" : "Scarica audio",
    "Keyboard shortcut" : "Scorciatoia da tastiera",
    "Description" : "Descrizione",
    "right" : "destra",
    "Jump to next article" : "Salta all'articolo successivo",
    "left" : "sinistra",
    "Jump to previous article" : "Salta all'articolo precedente",
    "Toggle star article" : "Commuta l'aggiunta ai preferiti di un articolo",
    "Star article and jump to next one" : "Aggiungi l'articolo ai preferiti e salta al successivo",
    "Toggle keep current article unread" : "Commuta il mantenimento dell'articolo come non letto",
    "Open article in new tab" : "Apri articolo in una nuova scheda",
    "Toggle expand article in compact view" : "Commuta l'espansione dell'articolo nella vista compatta",
    "Load next feed" : "Carica la fonte successiva",
    "Load previous feed" : "Carica la fonte precendente",
    "Load next folder" : "Carica la cartella successiva",
    "Load previous folder" : "Carica la cartella precedente",
    "Scroll to active navigation entry" : "Scorri per attivare la voce di navigazione",
    "Focus search field" : "Evidenzia il campo di ricerca",
    "Mark current article's feed/folder read" : "Marca la cartella/fonte dell'articolo attuale come letta",
    "Web address" : "Indirizzo web",
    "Feed exists already!" : "La fonte esiste già!",
    "Folder" : "Cartella",
    "No folder" : "Nessuna cartella",
    "New folder" : "Nuova cartella",
    "Folder name" : "Nome della cartella",
    "Go back" : "Indietro",
    "Folder exists already!" : "La cartella esiste già!",
    "New Folder" : "Nuova cartella",
    "Create" : "Crea",
    "Explore" : "Esplora",
    "Deleted feed" : "Elimina la fonte",
    "Undo delete feed" : "Annulla l'eliminazione della fonte",
    "Rename" : "Rinomina",
    "Menu" : "Menu",
    "No feed ordering" : "Nessun ordine delle fonti",
    "Reversed feed ordering" : "Ordine inverso delle fonti",
    "Normal feed ordering" : "Ordine normale delle fonti",
    "Rename feed" : "Rinomina fonte",
    "Delete feed" : "Elimina la fonte",
    "Mark all articles read" : "Marca tutti come gli articoli come letti",
    "Dismiss" : "Annulla",
    "Collapse" : "Contrai",
    "Deleted folder" : "Elimina la cartella",
    "Undo delete folder" : "Annulla l'eliminazione della cartella",
    "Rename folder" : "Rinomina la cartella",
    "Delete folder" : "Elimina la cartella",
    "Starred" : "Preferiti",
    "Unread articles" : "Articoli non letti",
    "All articles" : "Tutti gli articoli",
    "Settings" : "Impostazioni",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Disable mark read through scrolling" : "Disabilita la marcatura come letto durante lo scorrimento",
    "Compact view" : "Visualizzazione compatta",
    "Expand articles on key navigation" : "Espandi gli articoli durante la navigazione con i tasti",
    "Show all articles" : "Mostra tutti gli articoli",
    "Reverse ordering (oldest on top)" : "Ordine inverso (più vecchio in alto)",
    "Subscriptions (OPML)" : "Sottoscrizioni (OPML)",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Error when importing: file does not contain valid OPML" : "Errore di importazione: il file non contiene OPML valido",
    "Unread/Starred Articles" : "Articoli non letti/preferiti",
    "Error when importing: file does not contain valid JSON" : "Errore durante l'importazione: il file non contiene JSON valido"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-news_6.0.4%2Bdfsg.orig.tar.gz: news-6.0.4/l10n/it.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "La fonte contiene XML non valido",
    "Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" : "Fonte non trovata: il sito web non fornisce una fonte o blocca l'accesso. Per evitare il blocco, prova a scaricare la fonte dalla riga di comando del tuo server utilizzando curl: curl http://la-fonte.tld",
    "Detected feed format is not supported" : "Il formato della fonte rilevato non è supportato",
    "SSL Certificate is invalid" : "Il certificato SSL non è valido",
    "Website not found" : "Sito web non trovato",
    "More redirects than allowed, aborting" : "Più redirezioni di quelle consentite, interruzione in corso",
    "Bigger than maximum allowed size" : "Più grande della dimensione massima consentita",
    "Request timed out" : "Richiesta scaduta",
    "Request failed, network connection unavailable!" : "Richiesta non riuscita, connessione di rete non disponibile!",
    "Request unauthorized. Are you logged in?" : "Richiesta non autorizzata. Hai effettuato l'accesso?",
    "Request forbidden. Are you an admin?" : "Richiesta vietata. Sei un amministratore?",
    "Token expired or app not enabled! Reload the page!" : "Token scaduto o applicazione non abilitata! Ricarica la pagina!",
    "Internal server error! Please check your " : "Errore interno del server! Controlla il tuo",
    "Request failed, ownCloud is in currently " : "Richiesta non riuscita, ownCloud è attualmente",
    "Can not add feed: Exists already" : "Impossible aggiungere la fonte: esiste già",
    "Articles without feed" : "Articoli senza fonte",
    "Can not add folder: Exists already" : "Impossibile aggiungere la cartella: esiste già",
    "Use ownCloud cron for updates" : "Utilizza il cron di ownCloud per gli aggiornamenti",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Disabilita questa opzione se esegui uno strumento di aggiornamento personalizzato come quello Python incluso nell'applicazione",
    "Purge interval" : "Intervallo di cancellazione",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Numero minimo di secondi dopo i quali le fonti e le cartelle eliminate sono rimosse dal database; valori inferiori a 60 secondi sono ignorati",
    "Maximum read count per feed" : "Numero massimo di letture per fonte",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Definisce la quantità massima di articoli che possono essere letti per ogni fonte che non saranno eliminati dall'operazione di pulitura; se vecchi articoli riappaiono dopo essere stati letti, incrementa questo valore; valori negativi come -1 disattiveranno completamente questa funzionalità",
    "Maximum redirects" : "Numero massimo di redizioni",
    "How many redirects the feed fetcher should follow" : "Quante redirezioni può seguire lo strumento di recupero delle fonti",
    "Maximum feed page size" : "Dimensione massima della pagina della fonte",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Dimensione massima in byte della fonte. Se la pagina RSS/Atom è più grande di questo valore, l'aggiornamento sarà interrotto",
    "Feed fetcher timeout" : "Ritardo massimo di attesa per il recupero della fonte",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Numero massimo di secondi di attesa per il caricamento di una fonte RSS o Atom; se richiede troppo tempo l'aggiornamento sarà interrotto",
    "Explore Service URL" : "URL del servizio Esplora",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Se specificato, questo URL del servizio sarà interrogato per visualizzare le fonti nella sezione di esplorazione. Per tornare al servizio di esplorazione integrato, lascia vuoto questo campo",
    "Saved" : "Salvato",
    "Download" : "Scarica",
    "Close" : "Chiudi",
    "Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "Rilevata la modalità Ajax o webcron di cron! Le tue fonti non saranno aggiornate correttamente. Si consiglia di utilizzare cron del sistema operativo o uno strumento di aggiornamento personalizzato.",
    "How to set up the operating system cron" : "Come configurare cron del sistema operativo",
    "How to set up a custom updater (faster and no possible deadlock) " : "Come configurare uno strumento di aggiornamento personalizzato (più veloce e senza blocchi)",
    "Subscribe" : "Sottoscrivi",
    "Refresh" : "Aggiorna",
    "No articles available" : "Nessun articolo disponibile",
    "No unread articles available" : "Non sono disponibili articoli non letti",
    "Open website" : "Apri sito web",
    "Star article" : "Aggiungi ai preferiti",
    "Unstar article" : "Rimuovi dai preferiti",
    "Keep article unread" : "Mantieni l'articolo come non letto",
    "Remove keep article unread" : "Rimuovi il mantenimento dell'articolo come non letto",
    "by" : "da",
    "from" : "da",
    "Play audio" : "Riproduci audio",
    "Download video" : "Scarica video",
    "Download audio" : "Scarica audio",
    "Keyboard shortcut" : "Scorciatoia da tastiera",
    "Description" : "Descrizione",
    "right" : "destra",
    "Jump to next article" : "Salta all'articolo successivo",
    "left" : "sinistra",
    "Jump to previous article" : "Salta all'articolo precedente",
    "Toggle star article" : "Commuta l'aggiunta ai preferiti di un articolo",
    "Star article and jump to next one" : "Aggiungi l'articolo ai preferiti e salta al successivo",
    "Toggle keep current article unread" : "Commuta il mantenimento dell'articolo come non letto",
    "Open article in new tab" : "Apri articolo in una nuova scheda",
    "Toggle expand article in compact view" : "Commuta l'espansione dell'articolo nella vista compatta",
    "Load next feed" : "Carica la fonte successiva",
    "Load previous feed" : "Carica la fonte precendente",
    "Load next folder" : "Carica la cartella successiva",
    "Load previous folder" : "Carica la cartella precedente",
    "Scroll to active navigation entry" : "Scorri per attivare la voce di navigazione",
    "Focus search field" : "Evidenzia il campo di ricerca",
    "Mark current article's feed/folder read" : "Marca la cartella/fonte dell'articolo attuale come letta",
    "Web address" : "Indirizzo web",
    "Feed exists already!" : "La fonte esiste già!",
    "Folder" : "Cartella",
    "No folder" : "Nessuna cartella",
    "New folder" : "Nuova cartella",
    "Folder name" : "Nome della cartella",
    "Go back" : "Indietro",
    "Folder exists already!" : "La cartella esiste già!",
    "New Folder" : "Nuova cartella",
    "Create" : "Crea",
    "Explore" : "Esplora",
    "Deleted feed" : "Elimina la fonte",
    "Undo delete feed" : "Annulla l'eliminazione della fonte",
    "Rename" : "Rinomina",
    "Menu" : "Menu",
    "Unpin feed from the top" : "Rimuovi fonte dalla cima",
    "Pin feed to the top" : "Appunta la fonte in cima",
    "No feed ordering" : "Nessun ordine delle fonti",
    "Reversed feed ordering" : "Ordine inverso delle fonti",
    "Normal feed ordering" : "Ordine normale delle fonti",
    "Enable full text feed fetching" : "Abilita il recupero dell'intero testo della fonte",
    "Disable full text feed fetching" : "Disabilita il recupero dell'intero testo della fonte",
    "Rename feed" : "Rinomina fonte",
    "Delete feed" : "Elimina la fonte",
    "Mark all articles read" : "Marca tutti come gli articoli come letti",
    "Dismiss" : "Annulla",
    "Collapse" : "Contrai",
    "Deleted folder" : "Elimina la cartella",
    "Undo delete folder" : "Annulla l'eliminazione della cartella",
    "Rename folder" : "Rinomina la cartella",
    "Delete folder" : "Elimina la cartella",
    "Starred" : "Preferiti",
    "Unread articles" : "Articoli non letti",
    "All articles" : "Tutti gli articoli",
    "Settings" : "Impostazioni",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Disable mark read through scrolling" : "Disabilita la marcatura come letto durante lo scorrimento",
    "Compact view" : "Visualizzazione compatta",
    "Expand articles on key navigation" : "Espandi gli articoli durante la navigazione con i tasti",
    "Show all articles" : "Mostra tutti gli articoli",
    "Reverse ordering (oldest on top)" : "Ordine inverso (più vecchio in alto)",
    "Subscriptions (OPML)" : "Sottoscrizioni (OPML)",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Error when importing: file does not contain valid OPML" : "Errore di importazione: il file non contiene OPML valido",
    "Unread/Starred Articles" : "Articoli non letti/preferiti",
    "Error when importing: file does not contain valid JSON" : "Errore durante l'importazione: il file non contiene JSON valido"
},
"nplurals=2; plural=(n != 1);");
